import castorcito_fields from '../castorcito_fields.js';

export default {
  components: {
    'castorcito-fields': castorcito_fields
  },
  props: [
    'fieldModel',
    'componentFieldSettings',
    'fieldBaseName',
    'fieldName'
  ],
  data() {
    const { components: allComponents, components_fields_settings: componentsFieldsSettings } = drupalSettings;
    const { min, max, add_button_label: addButtonLabel, delete_button_label: deleteButtonLabel, allowed_children: allowedChildren } = this.componentFieldSettings.settings;

    return {
      allComponents,
      componentsFieldsSettings,
      allowedChildren,
      min,
      max,
      addButtonLabel,
      deleteButtonLabel,
      selectedComponent: ''
    };
  },
  created() {
    if (!this.hasMultipleComponents && !this.fieldModel.items.length) {
      this.fieldModel.items.push(JSON.parse(JSON.stringify(this.allComponents[Object.keys(this.allowedChildren)[0]])));
    }
  },
  methods: {
    addItem() {
      const component = this.hasMultipleComponents ? this.selectedComponent : Object.keys(this.allowedChildren)[0];
      this.fieldModel.items.push(JSON.parse(JSON.stringify(this.allComponents[component])));
    },
    deleteItem: function(event, items, key) {
      items.splice(parseInt(key), 1);
    },
    formData(field) {
      return {
        componentModel: field,
        fieldsSettings: this.componentsFieldsSettings[field.type]
      };
    },
    labelDefault(item, i) {
      const order = i + 1;
      let label = 'Item - ' + order;
      if (this.componentFieldSettings.label !== item.label) {
        label = item.label;
      }

      return label;
    }
  },
  computed: {
    hasMultipleComponents() {
      return Object.keys(this.allowedChildren).length > 1;
    },
  },
  template: `
    <fieldset class="fieldset js-form-item form-item js-form-wrapper form-wrapper castorcito-field-container">
      <legend class="fieldset__legend fieldset__legend--visible">
        <span v-if="!componentFieldSettings.hide_label" class="fieldset__label">{{ componentFieldSettings.label }}</span>
      </legend>
      <div class="fieldset__wrapper">
        <div class="form-item__description">{{ componentFieldSettings.description }}</div>
        <details v-for="(item, i) in fieldModel.items" open class="claro-details" data-once="details">
          <summary role="button" aria-expanded="true" class="claro-details__summary">
            <span v-text="labelDefault(item, i)"></span>
            <span class="claro-details__summary-summary"></span>
          </summary>
          <div class="castorcito-container">
            <castorcito-fields
              :formData="formData(item)"
              :fieldBaseName="fieldBaseName"
              :containerDelta="i + '_' + componentFieldSettings.name" />
              <button v-if="fieldModel.items.length > 1" type="button" class="button--small button--danger button" @click="deleteItem($event, fieldModel.items, i)">{{ deleteButtonLabel }}</button>
          </div>
        </details>
        <div v-if="fieldModel.items.length < max" class="form-item castorcito-container--add-item">
          <div class="form-item--editor-format form-item form-type--select">
            <label v-if="hasMultipleComponents" :for="fieldName + '_add_item_select'" class="form-item__label visually-hidden">items</label>
            <select
              v-if="hasMultipleComponents"
              class="form-select form-element form-element--type-select"
              v-model="selectedComponent"
              :id="fieldName + '_add_item_select'">
              <option value="" disabled selected>Select an option</option>
              <option v-for="(child, key) in allowedChildren" :key="key" :value="key">{{ allComponents[child].label }}</option>
            </select>
            <button type="button" class="button button--action button--primary" @click="addItem">{{ addButtonLabel }}</button>
          </div>
        </div>
      </div>
    </fieldset>
  `
};
