export default {
  props: ['fieldModel', 'componentFieldSettings', 'fieldName'],
  data () {
    const { options, condition: isConditional,  conditions: fieldConditions } = this.componentFieldSettings.settings;
    this.fieldModel.value = options[0].key;

    return {
      options,
      isConditional,
      fieldConditions,
    };
  },
  mounted() {
    if (this.isConditional) {
      const selectElement = document.getElementById(this.fieldName);
      const formContainer = selectElement.closest('.castorcito-form--fields');
      this.updateFieldVisibility(formContainer, this.fieldConditions[0]);
    }
  },
  methods: {
    handleSelectChange(event) {
      const selectedKey = event.target.options[event.target.selectedIndex].getAttribute('data-key');
      const formContainer = event.target.closest('.castorcito-form--fields');
      this.updateFieldVisibility(formContainer, this.fieldConditions[selectedKey]);
    },
    updateFieldVisibility(formContainer, fieldConditions) {
      const fields = formContainer.querySelectorAll(':scope > div[data-field-name]');

      fields.forEach(field => {
        const fieldName = field.getAttribute('data-field-name');

        if (fieldName !== this.componentFieldSettings.name) {
          const shouldShow = fieldConditions.state === 'visible' && fieldConditions.fields[fieldName];
          const shouldHide = fieldConditions.state === 'invisible' && !fieldConditions.fields[fieldName];

          field.style.display = shouldShow || shouldHide ? 'block' : 'none';
        }
      });
    },
  },
  template: `
    <div class="form-item form-type--textfield">
      <div class="form-item form-type--select">
        <label v-if="!componentFieldSettings.hide_label" :for="fieldName" class="form-item__label">{{ componentFieldSettings.label }}</label>
        <select
          v-if="isConditional"
          class="form-select form-element form-element--type-select"
          v-model="fieldModel.value"
          @change="handleSelectChange"
          :id="fieldName">
          <option v-for="(option, key) in options" :key="key" :value="option.key" :data-key="key">{{ option.label }}</option>
        </select>
        <select
          v-else
          class="form-select form-element form-element--type-select"
          v-model="fieldModel.value"
          :id="fieldName">
          <option v-for="(option, key) in options" :key="key" :value="option.key">{{ option.label }}</option>
        </select>
        <div class="form-item__description">{{ componentFieldSettings.description }}</div>
      </div>
    </div>
  `
};
