const { defineAsyncComponent } = Vue;

export default {
  props: ['formData', 'fieldBaseName', 'containerDelta'],
  data() {
    return {
      showEditName: true
    };
  },
  computed: {
    buttonLabel() {
      return this.showEditName ? 'Mostrar edición de nombre' : 'Ocultar edición de nombre';
    }
  },
  template: `
    <div class="castorcito-form--fields">
      <div v-if="formData.fieldsSettings.settings.enable_edit_name" class="form-item">
        <label :for="fieldBaseName + '_label_' + containerDelta" class="form-item__label">{{ formData.componentModel.label }}</label>
        <button type="button" class="link action-link tabledrag-toggle-weight castorcito-edit-name" @click="toggleEditName">
          <span :class="['action-link action-link--extrasmall tabledrag-toggle-weight', {'action-link--icon-show': showEditName, 'action-link--icon-hide': !showEditName}]">{{ buttonLabel }}</span>
        </button>
        <input :id="fieldBaseName + '_label_' + containerDelta" :name="fieldBaseName + '_label_' + containerDelta" type="text" v-model="formData.componentModel.label" size="60" maxlength="255" :class="['text-full form-text form-element form-element--type-text form-element--api-textfield', {'hidden': showEditName}]" />
      </div>
      <div v-for="(field, index) in formData.componentModel.fields" :key="index" :data-field-name="index">
        <component
          :is="loadComponent(field.type)"
          :fieldModel="field"
          :componentFieldSettings="formData.fieldsSettings['fields'][index]"
          :fieldBaseName="fieldBaseName"
          :fieldName="fieldName(index)" />
      </div>
    </div>
  `,
  methods: {
    loadComponent(type) {
      return defineAsyncComponent(() => import(`./Fields/${type}.js`));
    },
    fieldName(name) {
      return `${this.fieldBaseName}_${name}_${this.containerDelta}`;
    },
    toggleEditName() {
      this.showEditName = !this.showEditName;
    }
  }
};
