<?php

namespace Drupal\castorcito;

use Drupal\Core\Config\Entity\ConfigEntityInterface;

/**
 * Provides an interface defining a Castorcito component entity type.
 */
interface CastorcitoComponentInterface extends ConfigEntityInterface {

  /**
   * get model of the component.
   *
   * @return array
   *   array model.
   */
  public function getModel();

  /**
   * Sets the component model.
   *
   * @param array $model
   *   The model of the component.
   *
   * @return $this
   *   The class instance this method is called on.
   */
  public function setModel($model);

  /**
   * Create the model of the component.
   *
   * @param string $label
   *  The component label.
   *
   * @return $this
   *   The class instance this method is called on.
   */
  public function setBaseModel($label);

  /**
   * Sets the field of the component.
   *
   * @param string $name, $field_model
   *  The name and model of the field.
   *
   * @return $this
   *   The class instance this method is called on.
   */
  public function setModelField($name, $field_model);

  /**
   * Set options in the component.
   *
   * @param array $options
   *   The options of the component.
   *
   * @return $this
   *   The class instance this method is called on.
   */
  public function setModelOptions($options);

  /**
   * Returns a specific field configuration.
   *
   * @param string $field
   *   The field machine name.
   *
   * @return \Drupal\castorcito\CastorcitoComponentFieldInterface
   *   The component field object.
   */
  public function getComponentField($field);

   /**
   * Returns the field configuration for component.
   *
   * @return \Drupal\castorcito\CastorcitoComponentFieldPluginCollection|\Drupal\castorcito\CastorcitoComponentFieldInterface[]
   *   The component field plugin collection.
   */
  public function getComponentFields();

  /**
   * Saves an field for component.
   *
   * @param array $configuration
   *   An array of field configuration.
   *
   * @return string
   *   The field name.
   */
  public function addComponentField(array $configuration);

  /**
   * Update an field configuration for component.
   *
   * @param array $configuration
   *   An array of field configuration.
   *
   * @return string
   *   The field name.
   */
  public function updateComponentFieldConfiguration(array $configuration);

  /**
   * Deletes an field from this component.
   *
   * @param \Drupal\castorcito\CastorcitoComponentFieldInterface $field
   *   The component field object.
   *
   * @return $this
   */
  public function deleteComponentField(CastorcitoComponentFieldInterface $field);
}
