<?php

namespace Drupal\castorcito;

use Drupal\Core\Config\Entity\ConfigEntityListBuilder;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Url;
/**
 * Provides a listing of Castorcito components.
 */
class CastorcitoComponentListBuilder extends ConfigEntityListBuilder {

  /**
   * {@inheritdoc}
   */
  public function buildHeader() {
    $header['label'] = $this->t('Label');
    $header['id'] = $this->t('Machine name');
    $header['description'] = $this->t('Description');
    return $header + parent::buildHeader();
  }

  /**
   * {@inheritdoc}
   */
  public function buildRow(EntityInterface $entity) {
    /** @var \Drupal\castorcito\CastorcitoComponentInterface $entity */
    $row['label'] = $entity->label();
    $row['id'] = $entity->id();
    $row['description'] = $entity->get('description');
    return $row + parent::buildRow($entity);
  }

  /**
   * {@inheritdoc}
   */
  public function getDefaultOperations(EntityInterface $entity) {
    $clone = [
      'title' => t('Clone'),
      'weight' => 200,
      'url' => $entity->toUrl('clone-form'),
    ];

    $operations = parent::getDefaultOperations($entity) + [
      'clone' => $clone,
    ];

    //Remove destination URL from the edit link to allow editing component
    //Component.
    if (isset($operations['edit'])) {
      $operations['edit']['url'] = $entity->toUrl('edit-form');
    }

    return $operations;
  }

  /**
   * {@inheritdoc}
   */
  public function render() {
    $build = parent::render();
    $build['table']['#empty'] = $this->t('There are currently no component. <a href=":url">Add a new one</a>.', [
      ':url' => Url::fromRoute('entity.castorcito_component.add_form')->toString(),
    ]);
    return $build;
  }
}
