<?php

namespace Drupal\castorcito\Form;

use Drupal\Core\Entity\EntityForm;
use Drupal\Core\Entity\EntityStorageInterface;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Base form for castorcito component add and edit forms.
 */
abstract class CastorcitoComponentFormBase extends EntityForm {

  /**
   * The entity being used by this form.
   *
   * @var \Drupal\castorcito\CastorcitoComponentInterface
   */
  protected $entity;

  /**
   * The castorcito component entity storage.
   *
   * @var \Drupal\Core\Entity\EntityStorageInterface
   */
  protected $componentStorage;

  /**
   * Constructs a base class for castorcito component add and edit forms.
   *
   * @param \Drupal\Core\Entity\EntityStorageInterface $component_storage
   *   The castorcito component entity storage.
   */
  public function __construct(EntityStorageInterface $component_storage) {
    $this->componentStorage = $component_storage;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('entity_type.manager')->getStorage('castorcito_component')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function form(array $form, FormStateInterface $form_state) {
    $form['components_configuration'] = [
      '#type' => 'details',
      '#title' => $this->t('Configuration'),
      '#open' => FALSE,
    ];

    $form['components_configuration']['label'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Component name'),
      '#default_value' => $this->entity->label(),
      '#required' => TRUE,
    ];

    $form['components_configuration']['id'] = [
      '#type' => 'machine_name',
      '#disabled' => !$this->entity->isNew(),
      '#machine_name' => [
        'exists' => [$this->componentStorage, 'load'],
        'source' => [
          'components_configuration',
          'label',
        ],
      ],
      '#default_value' => $this->entity->id(),
      '#required' => TRUE,
    ];

    $form['components_configuration']['description'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Description'),
      '#default_value' => $this->entity->get('description'),
    ];

    $form['components_configuration']['enable_edit_name'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable editing of component name'),
      '#description' => $this->t('Checking this option displays a button that allows you to define a component name for better content management.'),
      '#default_value' => $this->entity->get('enable_edit_name'),
    ];
    
    $form['components_configuration']['inside_container'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('This component is only for use inside a container'),
      '#default_value' => $this->entity->get('inside_container'),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function save(array $form, FormStateInterface $form_state) {
    parent::save($form, $form_state);
    $form_state->setRedirectUrl($this->entity->toUrl('edit-form'));
  }

}
