<?php

namespace Drupal\castorcito\Form;

use Drupal\Core\Ajax\AjaxResponse;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Ajax\CloseModalDialogCommand;
use Drupal\Core\Config\ConfigFactoryInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\castorcito\CastorcitoManager;

/**
 * Provides a config for castorcito widget.
 *
 * @internal
 */
class CastorcitoWidgetConfigForm extends ConfigFormBase {

  /**
   * The castorcito manager.
   *
   * @var Drupal\castorcito\CastorcitoManager;
   */
  protected $castorcitoManager;
  
  /**
   * The params widget config name.
   *
   * @var array;
   */
  protected $paramsWidgetConfigName = [];

  /**
   * Constructs a form.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The factory for configuration objects.
   * @param Drupal\castorcito\CastorcitoManager $castorcito_manager
   *   The castorcito manager.
   */
  public function __construct(ConfigFactoryInterface $config_factory, CastorcitoManager $castorcito_manager) {
    parent::__construct($config_factory);
    $this->castorcitoManager = $castorcito_manager;
    $this->paramsWidgetConfigName = [
      'entity_type' => $this->getRequest()->attributes->get('entity_type'),
      'bundle' => $this->getRequest()->attributes->get('bundle'),
      'field_name' => $this->getRequest()->attributes->get('field_name'),
    ];
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('castorcito.manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      $this->castorcitoManager->configWidgetName($this->paramsWidgetConfigName),
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'castorcito_widget_config';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config_name = $this->castorcitoManager->configWidgetName($this->paramsWidgetConfigName);
    $config_widget_field = $this->config($config_name);
    $components = $this->castorcitoManager->castorcitoComponentsOptions();

    $form['components'] = [
      '#type' => 'checkboxes',
      '#title' => $this->t('Components list'),
      '#options' => $components,
      '#default_value' => $config_widget_field->get('components') ?: [],
      '#required' => TRUE,
      '#multiple' => TRUE,
    ];

    $form['actions']['save_config'] = [
      '#type' => 'submit',
      '#value' => $this->t('Save config'),
      '#attributes' => [
        'class' => ['button--primary'],
      ],
      '#submit' => [],
      '#ajax' => [
        'callback' => '::submitForm',
        'event' => 'click',
      ],
    ];

    $form['actions']['cancel_config'] = [
      '#type' => 'button',
      '#value' => $this->t('Cancel'),
      '#ajax' => [
        'callback' => '::submitCancel',
        'event' => 'click',
      ],
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    parent::validateForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $components = $form_state->getValue('components');
    $config_name = $this->castorcitoManager->configWidgetName($this->paramsWidgetConfigName);

    $this->config($config_name)->set('components', $components)->save();
    $response = new AjaxResponse();
    $response->addCommand(new CloseModalDialogCommand());

    return $response;
  }

  /**
   * {@inheritdoc}
   */
  public function submitCancel(array &$form, FormStateInterface $form_state) {
    $response = new AjaxResponse();
    $response->addCommand(new CloseModalDialogCommand());

    return $response;
  }
}
