<?php

namespace Drupal\castorcito\Plugin\CastorcitoComponentField;

use Drupal\Core\Form\FormStateInterface;

/**
 * Container configuration.
 *
 * @CastorcitoComponentField(
 *   id = "advanced_container",
 *   label = @Translation("Advanced container"),
 *   description = @Translation("Configuration for the advanced container field.")
 * )
 */
class AdvancedContainer extends Container {

  /**
   * {@inheritdoc}
   */
  public function defaultModel() {
    return parent::defaultConfiguration() + [
      'items' => [
        [
          'head' => '',
          'body' => '',
        ],
      ],
    ];
  }


  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return parent::defaultConfiguration() + [
      'allowed_head' => [],
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    $form['allowed_head'] = [
      '#type' => 'checkboxes',
      '#title' => $this->t('Allowed Head'),
      '#options' => $this->componentList(),
      '#default_value' => $this->configuration['allowed_head'],
      '#description' => $this->t('Choose the necessary components for the header; You must have a component already created..'),
      '#required' => TRUE,
      '#multiple' => TRUE,
    ];

    $form = parent::buildConfigurationForm($form, $form_state);

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateConfigurationForm(array &$form, FormStateInterface $form_state) {
    if (empty($form_state->getValue('allowed_head'))) {
      $form_state->setErrorByName('error_field', $this->t('There are no components yet, you need to have a component to use this field.'));
    }

    parent::validateConfigurationForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state) {
    $this->configuration['allowed_head'] = $form_state->getValue('allowed_children');
    parent::submitConfigurationForm($form, $form_state);
  }
}
