<?php

namespace Drupal\castorcito\Plugin\CastorcitoComponentField;

use Drupal\Core\Field\FieldFilteredMarkup;
use Drupal\Core\Form\FormStateInterface;
use Drupal\castorcito\ConfigurableComponentFieldBase;

/**
 * Iframe configuration.
 *
 * @CastorcitoComponentField(
 *   id = "iframe",
 *   label = @Translation("Iframe"),
 *   description = @Translation("Configuration for the iframe field.")
 * )
 */
class Iframe extends ConfigurableComponentFieldBase {

  /**
   * {@inheritdoc}
   */
  public function defaultModel() {
    return [
      'provider' => 'iframe',
      'url' => '',
      'value' => '',
    ];
  }

   /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return parent::defaultConfiguration() + [
      'allowed_providers' => [],
      'vimeo_provider_details' => '',
      'youtube_provider_details' => '',
      'width' => 640,
      'height' => 360
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    $form['allowed_providers'] = [
      '#type' => 'checkboxes',
      '#options' => [
        'vimeo' => $this->t('Vimeo'),
        'youtube' => $this->t('YouTube'),
      ],
      '#title' => $this->t('Allowed Providers'),
      '#default_value' => $this->configuration['allowed_providers'],
      '#description' => $this->t('Restrict users from entering information from the following providers. If none are selected any video provider can be used.'),
    ];

    $form['vimeo_provider_details'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Vimeo Provider Details'),
      '#default_value' => $this->configuration['vimeo_provider_details'],
      '#description' => $this->t('Instructions to present to the user below this field on the editing form.<br />Allowed HTML tags: @tags', ['@tags' => FieldFilteredMarkup::displayAllowedTags()]) . '<br />',
      '#states' => [
        'visible' => [
          ':input[name="settings[allowed_providers][vimeo]"]' => ['checked' => TRUE],
        ],
      ],
    ];

    $form['youtube_provider_details'] = [
      '#type' => 'textarea',
      '#title' => $this->t('YouTube Provider Details'),
      '#default_value' => $this->configuration['youtube_provider_details'],
      '#description' => $this->t('Instructions to present to the user below this field on the editing form.<br />Allowed HTML tags: @tags', ['@tags' => FieldFilteredMarkup::displayAllowedTags()]) . '<br />',
      '#states' => [
        'visible' => [
          ':input[name="settings[allowed_providers][youtube]"]' => ['checked' => TRUE],
        ],
      ],
    ];

    $form['width'] = [
      '#type' => 'number',
      '#title' => $this->t('Width'),
      '#default_value' => $this->configuration['width'],
      '#description' => $this->t('Allows you to define a width for the video.'),
    ];

    $form['height'] = [
      '#type' => 'number',
      '#title' => $this->t('Height'),
      '#default_value' => $this->configuration['height'],
      '#description' => $this->t('Allows you to define a height for the video.'),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state) {
    $this->configuration['allowed_providers'] = array_filter($form_state->getValue('allowed_providers'));
    $this->configuration['vimeo_provider_details'] = $form_state->getValue('vimeo_provider_details');
    $this->configuration['youtube_provider_details'] = $form_state->getValue('youtube_provider_details');
    $this->configuration['width'] = $form_state->getValue('width');
    $this->configuration['height'] = $form_state->getValue('height');
  }
}
