<?php

namespace Drupal\castorcito\Plugin\CastorcitoComponentField;

use Drupal\Core\Form\FormStateInterface;
use Drupal\castorcito\ConfigurableComponentFieldBase;
use Drupal\Component\Utility\Environment;

/**
 * Image configuration.
 *
 * @CastorcitoComponentField(
 *   id = "image",
 *   label = @Translation("Imagen"),
 *   description = @Translation("Configuration for the image field.")
 * )
 */
class Image extends ConfigurableComponentFieldBase {

  /**
   * {@inheritdoc}
   */
  public function defaultModel() {
    return [
      'fid' => '',
      'name' => '',
      'size' => '',
      'value' => '',
      'thumbnail' => '',
      'title' => '',
      'alt' => '',
      'width' => '',
      'height' => ''
    ];
  }


  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return parent::defaultConfiguration() + [
      'extensions' => 'png, jpg, jpeg',
      'directory' => 'castorcito-images',
      'max_size' => '',
      'max_dimensions' => [
        'width' => '',
        'height' => ''
      ],
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    $form['extensions'] = [
      '#type' => 'textfield',
      '#default_value' => $this->configuration['extensions'],
      '#title' => $this->t('Allowed file extensions'),
      '#description' => $this->t("Separate extensions with a comma or space. Each extension can contain alphanumeric characters, '.', and '_', and should start and end with an alphanumeric character."),
    ];

    $form['directory'] = [
      '#type' => 'textfield',
      '#default_value' => $this->configuration['directory'],
      '#title' => $this->t('Upload directory'),
      '#description' => $this->t("A directory relative to Drupal's files directory where uploaded images will be stored."),
    ];

    $default_max_size = format_size(Environment::getUploadMaxSize());
    $form['max_size'] = [
      '#type' => 'textfield',
      '#default_value' => $this->configuration['max_size'],
      '#title' => $this->t('Maximum file size'),
      '#description' => $this->t('If this is left empty, then the file size will be limited by the PHP maximum upload size of @size.', ['@size' => $default_max_size]),
      '#maxlength' => 20,
      '#size' => 10,
      '#placeholder' => $default_max_size,
    ];


    $form['max_dimensions'] = [
      '#type' => 'item',
      '#title' => $this->t('Maximum dimensions'),
      '#description' => $this->t('Images larger than these dimensions will be scaled down.'),
    ];

    $form['max_dimensions']['width'] = [
      '#title' => $this->t('Width'),
      '#title_display' => 'invisible',
      '#type' => 'number',
      '#default_value' => $this->configuration['max_dimensions']['width'],
      '#size' => 8,
      '#maxlength' => 8,
      '#min' => 1,
      '#max' => 99999,
      '#placeholder' => $this->t('width'),
      '#field_suffix' => ' x ',
      '#prefix' => '<div class="form--inline clearfix">',
    ];

    $form['max_dimensions']['height'] = [
      '#title' => $this->t('Height'),
      '#title_display' => 'invisible',
      '#type' => 'number',
      '#default_value' => $this->configuration['max_dimensions']['height'],
      '#size' => 8,
      '#maxlength' => 8,
      '#min' => 1,
      '#max' => 99999,
      '#placeholder' => $this->t('height'),
      '#suffix' => '</div>',
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state) {
    $this->configuration['extensions'] = $form_state->getValue('extensions');
    $this->configuration['directory'] = $form_state->getValue('directory');
    $this->configuration['max_size'] = $form_state->getValue('max_size');
    $this->configuration['max_dimensions'] = $form_state->getValue('max_dimensions');
  }
}
